@@ -1,4 +1,3 @@
-# Copyright (c) 2023-2024 Löwenfelsen UG (haftungsbeschränkt)
 # Copyright (c) 2023-2024 Philipp Schafft
 
 # licensed under Artistic License 2.0 (see LICENSE file)
@@ -14,7 +13,7 @@ use parent qw(Digest::base);
 
 use Carp;
 
-our $VERSION = v0.19;
+our $VERSION = v0.20;
 
 
 # Private constructor:
@@ -62,7 +61,7 @@ Data::URIID::Digest - Extractor for identifiers from URIs
 
 =head1 VERSION
 
-version v0.19
+version v0.20
 
 =head1 SYNOPSIS
 
@@ -78,11 +77,11 @@ This module inherits from L<Digest::base>.
 
 =head1 AUTHOR
 
-Löwenfelsen UG (haftungsbeschränkt) <support@loewenfelsen.net>
+Philipp Schafft <lion@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2023-2025 by Löwenfelsen UG (haftungsbeschränkt) <support@loewenfelsen.net>.
+This software is Copyright (c) 2023-2025 by Philipp Schafft <lion@cpan.org>.
 
 This is free software, licensed under:
 
